@@ -3,8 +3,10 @@ from types import FunctionType
 import websockets
 import orjson
 import logging
+
+import winerp
 from .lib.message import WsMessage
-from .lib.payload import Payloads, MessagePayload
+from .lib.payload import Payloads, MessagePayload, winerpObject, responseObject
 from .lib.errors import *
 import uuid
 import traceback
@@ -79,7 +81,7 @@ class Client:
     async def send_message(self, data: Union[Any, WsMessage]):
         if not isinstance(data, WsMessage):
             data = data.__dict__
-
+        logger.debug(data)
         await self.websocket.send(orjson.dumps(data).decode("utf-8"))
     
     def __send_message(self, data):
@@ -461,6 +463,10 @@ class Client:
 
         try:
             payload.data = await func(**data)
+            if type(payload.data) == winerpObject:
+                payload.pseudo_object = True
+                payload.data = payload.data.serialize()
+
         except Exception as error:
             logger.exception(error)
             self._dispatch_event('winerp_error', error)
@@ -499,7 +505,10 @@ class Client:
         
         future: asyncio.Future = self.listeners[_uuid]
         if not msg.type.error:
-            future.set_result(data)
+            if msg.pseudo_object:
+                future.set_result(responseObject(data))
+            else:
+                future.set_result(data)
         else:
             future.set_exception(
                 ClientRuntimeError(msg.data)
